@@ -17,9 +17,7 @@
  */
 class KapmanParser
 {
-
 private:
-
     /** The Game to initialize */
     Game *m_game;
 
@@ -28,8 +26,8 @@ private:
 
     /** The rows counter */
     int m_counterRows;
-public:
 
+public:
     /**
      * Creates a new GameParser.
      * @param p_game the Game to initialize
@@ -40,17 +38,20 @@ public:
      * Deletes the GameParser instance.
      */
     ~KapmanParser();
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     bool characters(const QStringRef &ch);
 
-    bool startElement(const QStringRef &namespaceURI, const QStringRef &localName,
-                      const QStringRef &qName, const QXmlStreamAttributes &atts);
+    bool startElement(const QStringRef &namespaceURI, const QStringRef &localName, const QStringRef &qName, const QXmlStreamAttributes &atts);
 
-    bool endElement(const QStringRef &namespaceURI,
-                    const QStringRef &localName, const QStringRef &qName);
+    bool endElement(const QStringRef &namespaceURI, const QStringRef &localName, const QStringRef &qName);
+#else
+    bool characters(const QStringView &ch);
 
+    bool startElement(const QStringView &namespaceURI, const QStringView &localName, const QStringView &qName, const QXmlStreamAttributes &atts);
+
+    bool endElement(const QStringView &namespaceURI, const QStringView &localName, const QStringView &qName);
+#endif
     bool parse(QIODevice *input);
 };
 
 #endif
-
